@@ -7,28 +7,27 @@
 # Licence: https://opensource.org/licenses/GPL-3.0
 #########################################
 
-# TODO - Go through with these steps:
-# https://packaging.python.org/tutorials/packaging-projects/
-
-import subprocess, os, fnmatch, pathlib
+import subprocess
+import os
+import fnmatch
+import pathlib
 from collections import OrderedDict
-from datetime import datetime, time, timedelta
+from datetime import datetime, timedelta
 
 
-'''
-ZFS connection classes
-'''
+# ZFS connection classes
 class Connection:
     host = None
     _poolset = None
     _dirty = True
     _trust = False
     _properties = None
-    def __init__(self,host="localhost", trust=False, sshcipher=None, properties=None, identityfile=None, knownhostsfile=None, verbose=False):
+
+    def __init__(self, host="localhost", trust=False, sshcipher=None, properties=None, identityfile=None, knownhostsfile=None, verbose=False):
         self.host = host
         self._trust = trust
         self._properties = properties if properties else []
-        self._poolset= PoolSet(self)
+        self._poolset = PoolSet(self)
         self.verbose = verbose
         self._pools_loaded = False
         if host in ['localhost','127.0.0.1']:
@@ -46,8 +45,8 @@ class Connection:
                 self.command.extend(["-o","UserKnownHostsFile=%s" % knownhostsfile])
             self.command.extend([self.host])
 
-    def get_poolset(self):
-        if self._dirty:
+    def get_poolset(self, force:bool=False):
+        if force or  self._dirty:
             properties = [ 'creation' ] + self._properties
             stdout2 = subprocess.check_output(self.command + ["zfs", "list", "-Hpr", "-o", ",".join( ['name'] + properties ), "-t", "all"])
 
@@ -66,8 +65,6 @@ class Connection:
         self._dirty = True
 
 
-''' Models '''
-
 
 # ZFSItem is an 'abstract' class for Pool, Dataset and Snapshot
 class ZFSItem(object):
@@ -676,6 +673,7 @@ class Diff():
     __repr__ = __str__
 
 
+
 # Will resolve Pool and Datastore for a path on local filesystem using the mountpoint
 # returns (Pool, DataStore, Real_Path, Relative_Path)
 def find_datastore_for_path(poolset:PoolSet, path:str) -> tuple:
